==> youtui-center-api-0.0.1.7-lichao3-20180704.025617-1-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiActivityDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import cn.com.duiba.tuia.youtui.center.api.common.BaseDto;

import java.io.Serializable;
import java.util.Date;


/**
 * Created by xuefeng on 2018/5/17.
 */
public class YoutuiActivityDto extends BaseDto implements Serializable {

    private final static long SerialVersionUID = 1L;

    private Long id;

    private Boolean isDeleted;

    /**
     * title:活动标题.
     */
    private String title;

    /**
     * activityType:活动类型.
     */
    private Integer activityType;

    /**
     * limitCount:限制次数.
     */
    private Integer limitCount;

    /**
     * limitScope:限制范围.
     */
    private String limitScope;

    /**
     * tag:标签.
     */
    private String tag;

    /**
     * activityPlanner:活动策划.
     */
    private String activityPlanner;

    /**
     * visionPlanner:视觉策划.
     */
    private String visionPlanner;

    /**
     * urlInfo:图片url.
     */
    private String urlInfo;

    /**
     * isOpen:是否开启,0/1 开启/关闭.
     */
    private Boolean isOpen;

    /**
     * autoOffDate:自动关闭时间.
     */
    private Date autoOffDate;

    /**
     * app内展示的素材图片.
     */
    private String appMaterialImg;

    /**
     * app内玩法说明图片.
     */
    private String appInstructionImg;

    /**
     * 额外信息
     */
    private String extInfo;

    /**
     * 玩法说明
     */
    private String instruction;

    /**
     * 活动子类
     **/
    private String subType;

    private Integer shareType;
    /**
     * 是否被置顶
     **/
    private Long isTopSort;

    private Long cyapId;

    /** subTitle:活动副标题. */
    private String subTitle;

    /** 微信分享快照图片. */
    private String wxSnapshotImg;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Boolean getDeleted() {
        return isDeleted;
    }

    public void setDeleted(Boolean deleted) {
        isDeleted = deleted;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }

    public String getLimitScope() {
        return limitScope;
    }

    public void setLimitScope(String limitScope) {
        this.limitScope = limitScope;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getActivityPlanner() {
        return activityPlanner;
    }

    public void setActivityPlanner(String activityPlanner) {
        this.activityPlanner = activityPlanner;
    }

    public String getVisionPlanner() {
        return visionPlanner;
    }

    public void setVisionPlanner(String visionPlanner) {
        this.visionPlanner = visionPlanner;
    }

    public String getUrlInfo() {
        return urlInfo;
    }

    public void setUrlInfo(String urlInfo) {
        this.urlInfo = urlInfo;
    }

    public Boolean getOpen() {
        return isOpen;
    }

    public void setOpen(Boolean open) {
        isOpen = open;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public String getAppMaterialImg() {
        return appMaterialImg;
    }

    public void setAppMaterialImg(String appMaterialImg) {
        this.appMaterialImg = appMaterialImg;
    }

    public String getAppInstructionImg() {
        return appInstructionImg;
    }

    public void setAppInstructionImg(String appInstructionImg) {
        this.appInstructionImg = appInstructionImg;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getInstruction() {
        return instruction;
    }

    public void setInstruction(String instruction) {
        this.instruction = instruction;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getShareType() {
        return shareType;
    }

    public void setShareType(Integer shareType) {
        this.shareType = shareType;

    }

    public Long getIsTopSort() {
        return isTopSort;
    }

    public void setIsTopSort(Long isTopSort) {
        this.isTopSort = isTopSort;
    }

    public Long getCyapId() {
        return cyapId;
    }

    public void setCyapId(Long cyapId) {
        this.cyapId = cyapId;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public String getWxSnapshotImg() {
        return wxSnapshotImg;
    }

    public void setWxSnapshotImg(String wxSnapshotImg) {
        this.wxSnapshotImg = wxSnapshotImg;
    }
}

==> youtui-center-api-0.0.1.11-lichao1-20180728.060309-6-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiActivityDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import cn.com.duiba.tuia.youtui.center.api.common.BaseDto;

import java.io.Serializable;
import java.util.Date;


/**
 * Created by xuefeng on 2018/5/17.
 */
public class YoutuiActivityDto extends BaseDto implements Serializable {

    private final static long SerialVersionUID = 1L;

    private Long id;

    private Boolean isDeleted;

    /**
     * title:活动标题.
     */
    private String title;

    /**
     * activityType:活动类型.
     */
    private Integer activityType;

    /**
     * limitCount:限制次数.
     */
    private Integer limitCount;

    /**
     * limitScope:限制范围.
     */
    private String limitScope;

    /**
     * tag:标签.
     */
    private String tag;

    /**
     * activityPlanner:活动策划.
     */
    private String activityPlanner;

    /**
     * visionPlanner:视觉策划.
     */
    private String visionPlanner;

    /**
     * urlInfo:图片url.
     */
    private String urlInfo;

    /**
     * isOpen:是否开启,0/1 开启/关闭.
     */
    private Boolean isOpen;

    /**
     * autoOffDate:自动关闭时间.
     */
    private Date autoOffDate;

    /**
     * app内展示的素材图片.
     */
    private String appMaterialImg;

    /**
     * app内玩法说明图片.
     */
    private String appInstructionImg;

    /**
     * 额外信息
     */
    private String extInfo;

    /**
     * 玩法说明
     */
    private String instruction;

    /**
     * 活动子类
     **/
    private String subType;

    private Integer shareType;
    /**
     * 是否被置顶
     **/
    private Long isTopSort;

    private Long cyapId;

    /** subTitle:活动副标题. */
    private String subTitle;

    /** h5标题 **/
    private String h5Title;
    /**
     * 微信分享图片
     **/
    private String wxShareImg;
    /**
     * 微信分享标题
     **/
    private String wxShareTitle;
    /**
     * 微信分享信息
     **/
    private String wxShareInfo;

    /** 微信分享快照图片. */
    private String wxSnapshotImg;

    /** 推广名称 */
    private String planTitle;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Boolean getDeleted() {
        return isDeleted;
    }

    public void setDeleted(Boolean deleted) {
        isDeleted = deleted;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }

    public String getLimitScope() {
        return limitScope;
    }

    public void setLimitScope(String limitScope) {
        this.limitScope = limitScope;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getActivityPlanner() {
        return activityPlanner;
    }

    public void setActivityPlanner(String activityPlanner) {
        this.activityPlanner = activityPlanner;
    }

    public String getVisionPlanner() {
        return visionPlanner;
    }

    public void setVisionPlanner(String visionPlanner) {
        this.visionPlanner = visionPlanner;
    }

    public String getUrlInfo() {
        return urlInfo;
    }

    public void setUrlInfo(String urlInfo) {
        this.urlInfo = urlInfo;
    }

    public Boolean getOpen() {
        return isOpen;
    }

    public void setOpen(Boolean open) {
        isOpen = open;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public String getAppMaterialImg() {
        return appMaterialImg;
    }

    public void setAppMaterialImg(String appMaterialImg) {
        this.appMaterialImg = appMaterialImg;
    }

    public String getAppInstructionImg() {
        return appInstructionImg;
    }

    public void setAppInstructionImg(String appInstructionImg) {
        this.appInstructionImg = appInstructionImg;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getInstruction() {
        return instruction;
    }

    public void setInstruction(String instruction) {
        this.instruction = instruction;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getShareType() {
        return shareType;
    }

    public void setShareType(Integer shareType) {
        this.shareType = shareType;

    }

    public Long getIsTopSort() {
        return isTopSort;
    }

    public void setIsTopSort(Long isTopSort) {
        this.isTopSort = isTopSort;
    }

    public Long getCyapId() {
        return cyapId;
    }

    public void setCyapId(Long cyapId) {
        this.cyapId = cyapId;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public String getH5Title() {
        return h5Title;
    }

    public void setH5Title(String h5Title) {
        this.h5Title = h5Title;
    }

    public String getWxShareImg() {
        return wxShareImg;
    }

    public void setWxShareImg(String wxShareImg) {
        this.wxShareImg = wxShareImg;
    }

    public String getWxShareTitle() {
        return wxShareTitle;
    }

    public void setWxShareTitle(String wxShareTitle) {
        this.wxShareTitle = wxShareTitle;
    }

    public String getWxShareInfo() {
        return wxShareInfo;
    }

    public void setWxShareInfo(String wxShareInfo) {
        this.wxShareInfo = wxShareInfo;
    }

    public String getWxSnapshotImg() {
        return wxSnapshotImg;
    }

    public void setWxSnapshotImg(String wxSnapshotImg) {
        this.wxSnapshotImg = wxSnapshotImg;
    }

    public String getPlanTitle() {
        return planTitle;
    }

    public void setPlanTitle(String planTitle) {
        this.planTitle = planTitle;
    }
}
